=====
API
=====

This page details the classes and methods provided by the ``py21cmfish`` module.

Parameters Class
===================

.. autoclass:: py21cmfish.Parameter
   :inherited-members:

Fisher matrix functions
========================

.. automodule:: py21cmfish.fishy
	:members:

Power spectra functions
========================

.. automodule:: py21cmfish.power_spectra
	:members:
